@@ -129,7 +129,7 @@ use twilight_validate::{
 /// use twilight_http::Client;
 ///
 /// let bearer = env::var("BEARER_TOKEN")?;
-/// let token = format!("Bearer {}", bearer);
+/// let token = format!("Bearer {bearer}");
 ///
 /// let client = Client::new(token);
 /// # Ok(()) }
@@ -686,7 +686,7 @@ impl Client {
         &'a self,
         guild_id: Id<GuildMarker>,
         name: &'a str,
-        image: &'a str,
+        image: &'a [u8],
     ) -> CreateEmoji<'a> {
         CreateEmoji::new(self, guild_id, name, image)
     }
@@ -1867,16 +1867,23 @@ impl Client {
     /// let channel_id = Id::new(123);
     ///
     /// let webhook = client
-    ///     .create_webhook(channel_id, "Twily Bot")
+    ///     .create_webhook(channel_id, "Twily Bot")?
     ///     .exec()
     ///     .await?;
     /// # Ok(()) }
     /// ```
-    pub const fn create_webhook<'a>(
+    ///
+    /// # Errors
+    ///
+    /// Returns an error of type [`WebhookUsername`] if the webhook's name is
+    /// invalid.
+    ///
+    /// [`WebhookUsername`]: twilight_validate::request::ValidationErrorType::WebhookUsername
+    pub fn create_webhook<'a>(
         &'a self,
         channel_id: Id<ChannelMarker>,
         name: &'a str,
-    ) -> CreateWebhook<'a> {
+    ) -> Result<CreateWebhook<'a>, ValidationError> {
         CreateWebhook::new(self, channel_id, name)
     }
 
@@ -2045,7 +2052,7 @@ impl Client {
     ///
     /// ```no_run
     /// # use twilight_http::Client;
-    /// use twilight_model::{datetime::Timestamp, id::Id};
+    /// use twilight_model::{id::Id, util::Timestamp};
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("token".to_owned());
@@ -2070,7 +2077,7 @@ impl Client {
     ///
     /// ```no_run
     /// # use twilight_http::Client;
-    /// use twilight_model::{datetime::Timestamp, id::Id};
+    /// use twilight_model::{id::Id, util::Timestamp};
     /// # #[tokio::main]
     /// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
     /// # let client = Client::new("token".to_owned());
@@ -2176,7 +2183,7 @@ impl Client {
     /// let id = Id::new(123);
     /// let sticker = client.sticker(id).exec().await?.model().await?;
     ///
-    /// println!("{:#?}", sticker);
+    /// println!("{sticker:#?}");
     /// # Ok(()) }
     /// ```
     pub const fn sticker(&self, sticker_id: Id<StickerMarker>) -> GetSticker<'_> {
@@ -2251,7 +2258,7 @@ impl Client {
     ///     .model()
     ///     .await?;
     ///
-    /// println!("{:#?}", sticker);
+    /// println!("{sticker:#?}");
     /// # Ok(()) }
     /// ```
     pub const fn guild_sticker(
@@ -2288,7 +2295,7 @@ impl Client {
     ///     .model()
     ///     .await?;
     ///
-    /// println!("{:#?}", sticker);
+    /// println!("{sticker:#?}");
     /// # Ok(()) }
     /// ```
     pub fn create_guild_sticker<'a>(
@@ -2324,7 +2331,7 @@ impl Client {
     ///     .model()
     ///     .await?;
     ///
-    /// println!("{:#?}", sticker);
+    /// println!("{sticker:#?}");
     /// # Ok(()) }
     /// ```
     pub const fn update_guild_sticker(
@@ -2403,9 +2410,8 @@ impl Client {
         let protocol = if self.use_http { "http" } else { "https" };
         let host = self.proxy.as_deref().unwrap_or("discord.com");
 
-        let url = format!("{}://{}/api/v{}/{}", protocol, host, API_VERSION, path);
-        #[cfg(feature = "tracing")]
-        tracing::debug!("URL: {:?}", url);
+        let url = format!("{protocol}://{host}/api/v{API_VERSION}/{path}");
+        tracing::debug!("URL: {url:?}");
 
         let mut builder = hyper::Request::builder().method(method.to_http()).uri(&url);
 
