@@ -1,27 +1,31 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::ListBody, ResponseFuture},
     routing::Route,
 };
 use twilight_model::{
     application::command::permissions::GuildCommandPermissions,
-    id::{ApplicationId, GuildId},
+    id::{
+        marker::{ApplicationMarker, GuildMarker},
+        Id,
+    },
 };
 
 /// Get command permissions for all commands from the current application in a guild.
 #[must_use = "requests must be configured and executed"]
 pub struct GetGuildCommandPermissions<'a> {
-    application_id: ApplicationId,
-    guild_id: GuildId,
+    application_id: Id<ApplicationMarker>,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
 }
 
 impl<'a> GetGuildCommandPermissions<'a> {
     pub(crate) const fn new(
         http: &'a Client,
-        application_id: ApplicationId,
-        guild_id: GuildId,
+        application_id: Id<ApplicationMarker>,
+        guild_id: Id<GuildMarker>,
     ) -> Self {
         Self {
             application_id,
@@ -34,11 +38,20 @@ impl<'a> GetGuildCommandPermissions<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<ListBody<GuildCommandPermissions>> {
-        let request = Request::from_route(&Route::GetGuildCommandPermissions {
-            application_id: self.application_id.get(),
-            guild_id: self.guild_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for GetGuildCommandPermissions<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::GetGuildCommandPermissions {
+            application_id: self.application_id.get(),
+            guild_id: self.guild_id.get(),
+        }))
     }
 }
