@@ -1,8 +1,7 @@
-pub mod create_stage_instance;
-pub mod update_stage_instance;
-
+mod create_stage_instance;
 mod delete_stage_instance;
 mod get_stage_instance;
+mod update_stage_instance;
 
 pub use self::{
     create_stage_instance::CreateStageInstance, delete_stage_instance::DeleteStageInstance,
