@@ -1,10 +1,14 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::EmptyBody, ResponseFuture},
     routing::Route,
 };
-use twilight_model::id::{ChannelId, UserId};
+use twilight_model::id::{
+    marker::{ChannelMarker, UserMarker},
+    Id,
+};
 
 /// Remove another member from a thread.
 ///
@@ -17,13 +21,17 @@ use twilight_model::id::{ChannelId, UserId};
 /// [`MANAGE_THREADS`]: twilight_model::guild::Permissions::MANAGE_THREADS
 #[must_use = "requests must be configured and executed"]
 pub struct RemoveThreadMember<'a> {
-    channel_id: ChannelId,
+    channel_id: Id<ChannelMarker>,
     http: &'a Client,
-    user_id: UserId,
+    user_id: Id<UserMarker>,
 }
 
 impl<'a> RemoveThreadMember<'a> {
-    pub(crate) const fn new(http: &'a Client, channel_id: ChannelId, user_id: UserId) -> Self {
+    pub(crate) const fn new(
+        http: &'a Client,
+        channel_id: Id<ChannelMarker>,
+        user_id: Id<UserMarker>,
+    ) -> Self {
         Self {
             channel_id,
             http,
@@ -35,11 +43,20 @@ impl<'a> RemoveThreadMember<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let request = Request::from_route(&Route::RemoveThreadMember {
-            channel_id: self.channel_id.get(),
-            user_id: self.user_id.get(),
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for RemoveThreadMember<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::RemoveThreadMember {
+            channel_id: self.channel_id.get(),
+            user_id: self.user_id.get(),
+        }))
     }
 }
