@@ -1,11 +1,12 @@
 use crate::{
     client::Client,
     error::Error,
-    request::{self, AuditLogReason, AuditLogReasonError, Request, TryIntoRequest},
+    request::{self, AuditLogReason, Request, TryIntoRequest},
     response::{marker::EmptyBody, ResponseFuture},
     routing::Route,
 };
 use twilight_model::id::{marker::WebhookMarker, Id};
+use twilight_validate::request::{audit_reason as validate_audit_reason, ValidationError};
 
 struct DeleteWebhookParams<'a> {
     token: Option<&'a str>,
@@ -51,8 +52,10 @@ impl<'a> DeleteWebhook<'a> {
 }
 
 impl<'a> AuditLogReason<'a> for DeleteWebhook<'a> {
-    fn reason(mut self, reason: &'a str) -> Result<Self, AuditLogReasonError> {
-        self.reason.replace(AuditLogReasonError::validate(reason)?);
+    fn reason(mut self, reason: &'a str) -> Result<Self, ValidationError> {
+        validate_audit_reason(reason)?;
+
+        self.reason.replace(reason);
 
         Ok(self)
     }
