@@ -13,12 +13,15 @@ use twilight_model::{
         Id,
     },
 };
-use twilight_validate::request::{audit_reason as validate_audit_reason, ValidationError};
+use twilight_validate::request::{
+    audit_reason as validate_audit_reason, webhook_username as validate_webhook_username,
+    ValidationError,
+};
 
 #[derive(Serialize)]
 struct UpdateWebhookFields<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
-    avatar: Option<NullableField<&'a str>>,
+    avatar: Option<NullableField<&'a [u8]>>,
     #[serde(skip_serializing_if = "Option::is_none")]
     channel_id: Option<Id<ChannelMarker>>,
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -56,7 +59,7 @@ impl<'a> UpdateWebhook<'a> {
     /// and `{data}` is the base64-encoded image. See [Discord Docs/Image Data].
     ///
     /// [Discord Docs/Image Data]: https://discord.com/developers/docs/reference#image-data
-    pub const fn avatar(mut self, avatar: Option<&'a str>) -> Self {
+    pub const fn avatar(mut self, avatar: Option<&'a [u8]>) -> Self {
         self.fields.avatar = Some(NullableField(avatar));
 
         self
@@ -70,10 +73,21 @@ impl<'a> UpdateWebhook<'a> {
     }
 
     /// Change the name of the webhook.
-    pub const fn name(mut self, name: Option<&'a str>) -> Self {
+    ///
+    /// # Errors
+    ///
+    /// Returns an error of type [`WebhookUsername`] if the webhook's name is
+    /// invalid.
+    ///
+    /// [`WebhookUsername`]: twilight_validate::request::ValidationErrorType::WebhookUsername
+    pub fn name(mut self, name: Option<&'a str>) -> Result<Self, ValidationError> {
+        if let Some(name) = name {
+            validate_webhook_username(name)?;
+        }
+
         self.fields.name = Some(NullableField(name));
 
-        self
+        Ok(self)
     }
 
     /// Execute the request, returning a future resolving to a [`Response`].
