@@ -1,12 +1,11 @@
-pub mod add_guild_member;
-pub mod get_guild_members;
-pub mod search_guild_members;
-pub mod update_guild_member;
-
+mod add_guild_member;
 mod add_role_to_member;
+mod get_guild_members;
 mod get_member;
 mod remove_member;
 mod remove_role_from_member;
+mod search_guild_members;
+mod update_guild_member;
 
 pub use self::{
     add_guild_member::AddGuildMember, add_role_to_member::AddRoleToMember,
