@@ -1,21 +1,26 @@
 use crate::{
     client::Client,
-    request::Request,
+    error::Error,
+    request::{Request, TryIntoRequest},
     response::{marker::EmptyBody, ResponseFuture},
     routing::Route,
 };
-use twilight_model::id::GuildId;
+use twilight_model::id::{marker::GuildMarker, Id};
 
 /// Delete a template by ID and code.
 #[must_use = "requests must be configured and executed"]
 pub struct DeleteTemplate<'a> {
-    guild_id: GuildId,
+    guild_id: Id<GuildMarker>,
     http: &'a Client,
     template_code: &'a str,
 }
 
 impl<'a> DeleteTemplate<'a> {
-    pub(crate) const fn new(http: &'a Client, guild_id: GuildId, template_code: &'a str) -> Self {
+    pub(crate) const fn new(
+        http: &'a Client,
+        guild_id: Id<GuildMarker>,
+        template_code: &'a str,
+    ) -> Self {
         Self {
             guild_id,
             http,
@@ -27,11 +32,20 @@ impl<'a> DeleteTemplate<'a> {
     ///
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
-        let request = Request::from_route(&Route::DeleteTemplate {
-            guild_id: self.guild_id.get(),
-            template_code: self.template_code,
-        });
+        let http = self.http;
 
-        self.http.request(request)
+        match self.try_into_request() {
+            Ok(request) => http.request(request),
+            Err(source) => ResponseFuture::error(source),
+        }
+    }
+}
+
+impl TryIntoRequest for DeleteTemplate<'_> {
+    fn try_into_request(self) -> Result<Request, Error> {
+        Ok(Request::from_route(&Route::DeleteTemplate {
+            guild_id: self.guild_id.get(),
+            template_code: self.template_code,
+        }))
     }
 }
