@@ -1,12 +1,11 @@
-pub mod get_current_user_guilds;
-pub mod update_current_user;
-
 mod create_private_channel;
 mod get_current_user;
 mod get_current_user_connections;
 mod get_current_user_guild_member;
+mod get_current_user_guilds;
 mod get_user;
 mod leave_guild;
+mod update_current_user;
 
 pub use self::{
     create_private_channel::CreatePrivateChannel, get_current_user::GetCurrentUser,
